@@ -1,5 +1,5 @@
 package Object::Anon;
-$Object::Anon::VERSION = '0.002';
+$Object::Anon::VERSION = '0.003';
 # ABSTRACT: Create objects on the fly
 
 use strict;
@@ -29,7 +29,8 @@ sub _objectify {
     }
     $seen->{$hash} = 1;
 
-    my $class = "Object::Anon::__ANON__::".$anon_class_id++;
+    my $class_id = $anon_class_id++;
+    my $class = "Object::Anon::__ANON__::".$class_id;
 
     for my $key (keys %$hash) {
         if ($overload_ops{$key}) {
@@ -41,6 +42,15 @@ sub _objectify {
         }
     }
 
+    do {
+      no strict 'refs';
+      *{$class."::DESTROY"} = sub {
+        my $symtab = *{$class.'::'}{HASH};
+        %$symtab = ();
+        delete *Object::Anon::__ANON__::{HASH}->{$class_id.'::'};
+      };
+    };
+
     return bless do { \my %o }, $class;
 }
 
@@ -61,16 +71,14 @@ __END__
 
 =pod
 
+=for markdown [![Build Status](https://secure.travis-ci.org/robn/Object-Anon.png)](http://travis-ci.org/robn/Object-Anon)
+
 =encoding UTF-8
 
 =head1 NAME
 
 Object::Anon - Create objects on the fly
 
-=head1 VERSION
-
-version 0.002
-
 =head1 SYNOPSIS
 
     use Object::Anon;
@@ -221,15 +229,6 @@ each time.
 
 =item *
 
-Class cleanup. Every generated class is used once and then never touched again.
-I think the overhead is mostly in symbol table stuff, which is fairly small,
-but in a long-running program that could quickly add up. I think I'd like to
-add a destructor to generated classes that scrubs the symbol table. First
-however I need to find a way of measuring the amount of memory used by the
-symbol table,
-
-=item *
-
 Overload clashes. Some overloaded operators are common words. If a hash had a
 key of that name it would generate an overload, not a method of that name,
 which isn't want you want. The only ways I can think of to deal with this is to
